@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.15.0";
+our $VERSION = "v0.15.1";
 
 1;
 __END__
@@ -264,9 +264,9 @@ L<https://rxjs.dev/api/index/class/Subject>
 
 L<https://rxjs.dev/api/index/function/throwError>
 
-    # 0, 1, 2, 3, error: foo
+    # 0, 1, 2, 3, foo, 4, 5, 6, ...
     rx_merge(
-        rx_throw_error('foo')->pipe( op_delay(4.5) ),
+        rx_of('foo')->pipe( op_delay(4.5) ),
         rx_interval(1),
     )->subscribe($subscriber);
 
